package dom.xpath;

import java.io.IOException;
import java.util.List;

import org.jdom2.Document;
import org.jdom2.Element;
import org.jdom2.JDOMException;
import org.jdom2.input.SAXBuilder;
import org.jdom2.xpath.XPathExpression;
import org.jdom2.xpath.XPathFactory;

import dom.MySaxErrorHandler;

/** 
 * How to use XPath expressions to search for <img>
 *  elements in XHTML document instances.
 *  
 * @author goik
 */
public class DomXpath {
   private final SAXBuilder builder = new SAXBuilder();

   public DomXpath() {
      builder.setErrorHandler(new MySaxErrorHandler(System.err));
   }
   /** 
    * Read an XHTML document and search for images. The image filenames will be
    * written to standard out.
    * @param xhtmlFilename The XHTML's filename to be examined.
    * @throws JDOMException 
    * @throws IOException
    */
   public void process(final String xhtmlFilename) throws JDOMException, IOException {

      final Document htmlInput = builder.build(xhtmlFilename);
      final XPathExpression<Object> xpath = XPathFactory.instance().compile("//img");
      final List<Object> images = xpath.evaluate(htmlInput);

      for (Object o: images) {
         final Element image = (Element ) o;
         System.out.print(image.getAttributeValue("src") + " "); 
      }
   }
}