package sda.jdbc.intro.auth;

import javax.swing.JComponent;
import javax.swing.JTextField;

/**
 * We may check user input from text fields in a generic way. 
 * defined by regular expressions. In addition error messages are forwarded
 * automatically to respective GUI elements.
 * 
 * @author goik
 */
public class EqualValueVerifier extends InputVerifierNotify {

   final JTextField compare;
   /**
    * For each input field to be validated we need the
    * following parameters:

    * @param regex The regular expression defining allowed textual content. The string
    *                "^[^ ]*$" for example allows arbitrary text not containing any spaces.
    * @param validationLabel  This is where error messages in case of rexex violation go.
    * @param errMsg      This text will be presented to the user in case of a validation error.
    */
   public EqualValueVerifier (final JTextField field, JTextField compare, final String errMsg) {
      super(field, errMsg);
      this.compare = compare;
   }

   @Override
   public boolean verify(JComponent input) {
      if (input instanceof JTextField) {
         if (((JTextField) input).getText().equals(compare.getText())) {
            validationLabel.setText("");
            return true;
         } else {
            validationLabel.setText(errorMessage);
         }
      }
      return false;
   }
}